#!/bin/bash

#author				: hennes (jm@rapidrabbit.de) -> original build-script by Michael Verret (AxXium)
#last changed		: 02-august-2007

#package			: jump'n bump
#homepage			: http://www.jumpbump.mine.nu/
#source location	: http://www.jumpbump.mine.nu/port/jumpnbump-1.55.tar.gz
#level location		: http://jumpnbump.spaceteddy.net/all-levels.tar.gz
#dependencies		: coreutils,cxxlibs,directfb,expat,fontconfig,freetype,gcc,gcc-g++,gdbm,libdrm,libjpeg,libpng,libtermcap,libtiff,mesa,ncurses,openssl,perl,sdl,sysfsutils,utempter,xorg,xterm,zlib

# ----- credentials
softname="jumpnbump"
softversion="1.55"
srcurl="http://www.jumpbump.mine.nu/port/jumpnbump-1.55.tar.gz"
levurl="http://jumpnbump.spaceteddy.net/all-levels.tar.gz"
arch=i486
cpu=i686
build="1"
zenversion="48"
packageversion="$zenversion.$build"

# ----- verify script
if [ "$(id -u)" != "0" ]; then
			echo "Please run as root!"
			exit 0
fi

# ----- help
if [ "${1}" = "--help" ]; then
	echo \
"$softname ZenBuild

usage:	--help 		Display this text
	--cleanup	Clean up after creating the package
"
	exit 0
fi

# ----- build parameters
numjobs="-j3"
builddir="$(pwd)"
package="$softname-$softversion-$arch-$packageversion"

# ----- prepare directories
dest="$builddir/$package"
rm -rf $dest
prefix="/usr"
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/$prefix/bin
mkdir -p $dest/usr/share/applications
mkdir -p $dest/usr/share/icons/hicolor/32x32/apps
mkdir -p $dest/usr/share/icons/hicolor/36x36/apps
mkdir -p $dest/usr/share/icons/hicolor/48x48/apps
mkdir -p $dest/usr/share/icons/hicolor/64x64/apps
mkdir -p $dest/usr/share/icons/hicolor/72x72/apps
mkdir -p $dest/usr/share/icons/hicolor/128x128/apps
mkdir -p $dest/usr/doc
mkdir -p $dest/usr/man/man6
destsrc="$dest/usr/src/$softname-$softversion"
mkdir -p $destsrc

# ----- make slack-desc-file
cat << EOF > $dest/install/slack-desc
         |-----handy-ruler------------------------------------------------------|
jumpnbump: jump'n bump (multiplayer eyecandy arcade game)
jumpnbump:
jumpnbump: You're a cute little bunny and you have to avoid the other
jumpnbump: bunnies from stomping on you and at the same time try to
jumpnbump: stomp as many opponents as possible. Jump & bump is multiplayer
jumpnbump: only with up to four players simultaneously. Gather the local
jumpnbump: crew and have a blast.
jumpnbump:
jumpnbump:
jumpnbump:
jumpnbump:
EOF

# ----- extract source-archive
srcdir=$softname-1.50
rm -rf $srcdir
if [ -f $softname-$softversion.tar.gz ]; then
   echo "looking for source-archive .. found"
else
   echo "looking for source-archive .. none found"
   wget -c $srcurl
fi
tar -zxvf $softname-$softversion.tar.gz

# ----- extract level-archive
levdir="levels"
rm -rf $levdir
if [ -f all-levels.tar.gz ]; then
   echo "looking for level-archive .. found"
else
   echo "looking for level-archive .. none found"
   wget -c $levurl
fi
tar -zxvf all-levels.tar.gz

# ----- create package-dependent directories
mkdir -p $dest/usr/doc/$softname-$softversion

# ----- set target-permissions
cd $levdir
chown -R root.root .
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 555 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
cd $builddir/$srcdir
chown -R root.root .
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 555 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;

# ----- configure
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"
./configure \
	--prefix=$prefix \
	--disable-debug
	
# ----- patch makefiles
sed -i 's|-Wall -O|-Wall|' \
  ./Makefile
sed -i 's|-Wall -O|-Wall|' \
  ./data/Makefile
sed -i 's|-Wall -O|-Wall|' \
  ./modify/Makefile
sed -i 's|-Wall -O|-Wall|' \
  ./sdl/Makefile

# ----- make
make $numjobs
	
# ----- make install
make install DESTDIR=$dest

# ----- add default-files
cp -a \
	AUTHORS COPYING ChangeLog LINKS README TODO \
	$dest/usr/doc/$softname-$softversion

# ----- treat icon-files
cd $builddir
tar -jxvf icons.tar.bz2 --directory=$builddir
mv icon-jumpnbump-32.png $dest/usr/share/icons/hicolor/32x32/apps/jumpnbump.png
mv icon-jumpnbump-36.png $dest/usr/share/icons/hicolor/36x36/apps/jumpnbump.png
mv icon-jumpnbump-48.png $dest/usr/share/icons/hicolor/48x48/apps/jumpnbump.png
mv icon-jumpnbump-64.png $dest/usr/share/icons/hicolor/64x64/apps/jumpnbump.png
mv icon-jumpnbump-72.png $dest/usr/share/icons/hicolor/72x72/apps/jumpnbump.png
mv icon-jumpnbump-128.png $dest/usr/share/icons/hicolor/128x128/apps/jumpnbump.png
cp icons.tar.bz2 $destsrc

# ----- make .desktop-file
cat << "EOF" > $dest/usr/share/applications/$softname.desktop
[Desktop Entry]
Name=Jump'n Bump
Comment=A multiplayer eyecandy arcade game
Exec=jumpnbump-xdialog
Icon=jumpnbump
Terminal=false
Type=Application
Categories=Game;ArcadeGame;
Encoding=UTF-8
EOF

# ----- copy build-file
cp "$builddir/build-$softname.sh" "$destsrc/build-$softname.sh"
chmod a+x "$destsrc/build-$softname.sh"

# ----- get-source-script
cat << EOF > "$destsrc/getsrc.sh"
wget -c $srcurl
EOF

chmod a+x "$destsrc/getsrc.sh"

# ----- install levels
cd $builddir/$levdir
for levelfile in $(find . | grep "dat.bz2") ; do
	bunzip2 -v $levelfile
	rm -f $levelfile
done
for leveldatfile in $(find . | grep "dat") ; do
	mv -v $leveldatfile $dest/usr/share/jumpnbump
done

# ----- remove uneeded files
rm $dest/usr/bin/jnbmenu.tcl
rm $dest/usr/bin/jumpnbump-kdialog
rm $dest/usr/bin/jumpnbump.fbcon
rm $dest/usr/bin/jumpnbump.svgalib

# ----- post-build processing
cd $dest
find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | \
	xargs strip --strip-unneeded 2> /dev/null
find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | \
	xargs strip --strip-unneeded 2> /dev/null
	
for mandir in $(find . -name man -type d) ; do
	if [ -d $mandir ]; then
		( cd $mandir
		  find . -type f -name "*.?" -exec gzip -9 {} \;
		)
	fi
done

# ----- packaging
chown -R root.root $dest/usr/bin
cd $dest
makepkg -l y -c n $dest.tgz
cd ..
md5sum $package.tgz > $package.md5

cat << "EOF" > $builddir/$package.dep
coreutils,cxxlibs,directfb,expat,fontconfig,freetype,gcc,gcc-g++,gdbm,libdrm,libjpeg,libpng,libtermcap,libtiff,mesa,ncurses,openssl,perl,sdl,sysfsutils,utempter,xorg,xterm,zlib
EOF

# ----- cleaning up
if [ "${1}" = "--cleanup" ]; then
rm -r $dest
rm -r $builddir/$srcdir
fi
